@@ -24,6 +24,7 @@
         "CUMSUM_PNL", "DFR", "PairGain", "Symbol", "aes", "asset_name",
 
         "Hold_NB", "MaxPerf", "NB_hold", "PnL_NB", "TR_Level", "X2_NB",
+        "qrtl", "value","FrstQntlPerf",
 
 
         # sample function names
@@ -35,7 +36,7 @@
         "predict", "read_rds", "summarise", "write.csv", "write_rds", "ymd_hms",
         "filter_all", "full_join", "bind_rows",  "as.h2o", "bind_cols", "testdir",
         "h2o.performance", "distinct", "dev.off", "geom_bar", "geom_line", "ggplot", "ggtitle", "pdf",
-        "sha512", "write_tsv", "encrypt_envelope", "mutate_at", "across"
+        "sha512", "write_tsv", "encrypt_envelope", "mutate_at", "across", "rename"
       )
     )
 
